#!/usr/bin/env python
"""Basic blinking led example.

The led on A20-OLinuXino-LIME2  blinks with rate of 1Hz like "heartbeat".
"""

import os
import sys

if not os.getegid() == 0:
    sys.exit('Script must be run as root')


from time import sleep
from pyA20Lime2.gpio import gpio
from pyA20Lime2.gpio import port

__author__ = "Stefan Mavrodiev"
__copyright__ = "Copyright 2014, Olimex LTD"
__credits__ = ["Stefan Mavrodiev"]
__license__ = "GPL"
__version__ = "2.0"
__maintainer__ = __author__
__email__ = "support@olimex.com"


led = port.PH2

gpio.init()
gpio.setcfg(led, gpio.OUTPUT)

try:
    print ("Press CTRL+C to exit")
    while True:
        gpio.output(led, 1)
        sleep(0.1)
        gpio.output(led, 0)
        sleep(0.1)

        gpio.output(led, 1)
        sleep(0.1)
        gpio.output(led, 0)
        sleep(0.1)

        sleep(0.6)
except KeyboardInterrupt:
    print ("Goodbye.")


__author__ = "Stefan Mavrodiev"
__copyright__ = "Copyright 2014, Olimex LTD"
__credits__ = ["Stefan Mavrodiev"]
__license__ = "GPL"
__version__ = "2.0"
__maintainer__ = __author__
__email__ = "support@olimex.com"


class Colors:
    def __init__(self):
        self = self

    def test(self):
        print "Regular"
        print self.Black + "Black" + self.Color_Off
        print self.Red + "Red" + self.Color_Off
        print self.Green + "Green" + self.Color_Off
        print self.Yellow + "Yellow" + self.Color_Off
        print self.Blue + "Blue" + self.Color_Off
        print self.Purple + "Purple" + self.Color_Off
        print self.Cyan + "Cyan" + self.Color_Off
        print self.White + "White" + self.Color_Off
        print ""

        print "Bold"
        print self.BBlack + "BBlack" + self.Color_Off
        print self.BRed + "BRed" + self.Color_Off
        print self.BGreen + "BGreen" + self.Color_Off
        print self.BYellow + "BYellow" + self.Color_Off
        print self.BBlue + "BBlue" + self.Color_Off
        print self.BPurple + "BPurple" + self.Color_Off
        print self.BCyan + "BCyan" + self.Color_Off
        print self.BWhite + "BWhite" + self.Color_Off
        print ""

        print "Underline"
        print self.UBlack + "UBlack" + self.Color_Off
        print self.URed + "URed" + self.Color_Off
        print self.UGreen + "UGreen" + self.Color_Off
        print self.UYellow + "UYellow" + self.Color_Off
        print self.UBlue + "UBlue" + self.Color_Off
        print self.UPurple + "UPurple" + self.Color_Off
        print self.UCyan + "UCyan" + self.Color_Off
        print self.UWhite + "UWhite" + self.Color_Off
        print ""

        print "Background"
        print self.On_Black + "On_Black" + self.Color_Off
        print self.On_Red + "On_Red" + self.Color_Off
        print self.On_Green + "On_Green" + self.Color_Off
        print self.On_Yellow + "On_Yellow" + self.Color_Off
        print self.On_Blue + "On_Blue" + self.Color_Off
        print self.On_Purple + "On_Purple" + self.Color_Off
        print self.On_Cyan + "On_Cyan" + self.Color_Off
        print self.On_White + "On_White" + self.Color_Off
        print ""

        print "High Intensity"
        print self.IBlack + "IBlack" + self.Color_Off
        print self.IRed + "IRed" + self.Color_Off
        print self.IGreen + "IGreen" + self.Color_Off
        print self.IYellow + "IYellow" + self.Color_Off
        print self.IBlue + "IBlue" + self.Color_Off
        print self.IPurple + "IPurple" + self.Color_Off
        print self.ICyan + "ICyan" + self.Color_Off
        print self.IWhite + "IWhite" + self.Color_Off
        print ""

        print "Bold High Intensity"
        print self.BIBlack + "BIBlack" + self.Color_Off
        print self.BIRed + "BIRed" + self.Color_Off
        print self.BIGreen + "BIGreen" + self.Color_Off
        print self.BIYellow + "BIYellow" + self.Color_Off
        print self.BIBlue + "BIBlue" + self.Color_Off
        print self.BIPurple + "BIPurple" + self.Color_Off
        print self.BICyan + "BICyan" + self.Color_Off
        print self.BIWhite + "BIWhite" + self.Color_Off
        print ""

        print "High Intensity backgrounds"
        print self.On_IBlack + "On_IBlack" + self.Color_Off
        print self.On_IRed + "On_IRed" + self.Color_Off
        print self.On_IGreen + "On_IGreen" + self.Color_Off
        print self.On_IYellow + "On_IYellow" + self.Color_Off
        print self.On_IBlue + "On_IBlue" + self.Color_Off
        print self.On_IPurple + "On_IPurple" + self.Color_Off
        print self.On_ICyan + "On_ICyan" + self.Color_Off
        print self.On_IWhite + "On_IWhite" + self.Color_Off
        print ""

    # Reset
    Color_Off = '\033[0m'  # Text Reset

    Black = '\033[0;30m'  # Black
    Red = '\033[0;31m'  # Red
    Green = '\033[0;32m'  # Green
    Yellow = '\033[0;33m'  # Yellow
    Blue = '\033[0;34m'  # Blue
    Purple = '\033[0;35m'  # Purple
    Cyan = '\033[0;36m'  # Cyan
    White = '\033[0;37m'  # White

    # Bold
    BBlack = '\033[1;30m'  # Black
    BRed = '\033[1;31m'  # Red
    BGreen = '\033[1;32m'  # Green
    BYellow = '\033[1;33m'  # Yellow
    BBlue = '\033[1;34m'  # Blue
    BPurple = '\033[1;35m'  # Purple
    BCyan = '\033[1;36m'  # Cyan
    BWhite = '\033[1;37m'  # White

    # Underline
    UBlack = '\033[4;30m'  # Black
    URed = '\033[4;31m'  # Red
    UGreen = '\033[4;32m'  # Green
    UYellow = '\033[4;33m'  # Yellow
    UBlue = '\033[4;34m'  # Blue
    UPurple = '\033[4;35m'  # Purple
    UCyan = '\033[4;36m'  # Cyan
    UWhite = '\033[4;37m'  # White

    # Background
    On_Black = '\033[40m'  # Black
    On_Red = '\033[41m'  # Red
    On_Green = '\033[42m'  # Green
    On_Yellow = '\033[43m'  # Yellow
    On_Blue = '\033[44m'  # Blue
    On_Purple = '\033[45m'  # Purple
    On_Cyan = '\033[46m'  # Cyan
    On_White = '\033[47m'  # White

    # High Intensity
    IBlack = '\033[0;90m'  # Black
    IRed = '\033[0;91m'  # Red
    IGreen = '\033[0;92m'  # Green
    IYellow = '\033[0;93m'  # Yellow
    IBlue = '\033[0;94m'  # Blue
    IPurple = '\033[0;95m'  # Purple
    ICyan = '\033[0;96m'  # Cyan
    IWhite = '\033[0;97m'  # White

    # Bold High Intensity
    BIBlack = '\033[1;90m'  # Black
    BIRed = '\033[1;91m'  # Red
    BIGreen = '\033[1;92m'  # Green
    BIYellow = '\033[1;93m'  # Yellow
    BIBlue = '\033[1;94m'  # Blue
    BIPurple = '\033[1;95m'  # Purple
    BICyan = '\033[1;96m'  # Cyan
    BIWhite = '\033[1;97m'  # White

    # High Intensity backgrounds
    On_IBlack = '\033[0;100m'  # Black
    On_IRed = '\033[0;101m'  # Red
    On_IGreen = '\033[0;102m'  # Green
    On_IYellow = '\033[0;103m'  # Yellow
    On_IBlue = '\033[0;104m'  # Blue
    On_IPurple = '\033[0;105m'  # Purple
    On_ICyan = '\033[0;106m'  # Cyan
    On_IWhite = '\033[0;107m'  # White


#!/usr/bin/env python
"""Read button.

Make gpio input and enable pull-up resistor.
"""

import os
import sys

if not os.getegid() == 0:
    sys.exit('Script must be run as root')


from pyA20Lime2.gpio import gpio
from pyA20Lime2.gpio import connector
from pyA20Lime2.gpio import port

__author__ = "Stefan Mavrodiev"
__copyright__ = "Copyright 2014, Olimex LTD"
__credits__ = ["Stefan Mavrodiev"]
__license__ = "GPL"
__version__ = "2.0"
__maintainer__ = __author__
__email__ = "support@olimex.com"

led = connector.gpio0p0     # This is the same as port.PH2
button = connector.gpio3p40

"""Init gpio module"""
gpio.init()

"""Set directions"""
gpio.setcfg(led, gpio.OUTPUT)
gpio.setcfg(button, gpio.INPUT)

"""Enable pullup resistor"""
gpio.pullup(button, gpio.PULLUP)
#gpio.pullup(button, gpio.PULLDOWN)     # Optionally you can use pull-down resistor

try:
    print ("Press CTRL+C to exit")
    while True:
        state = gpio.input(button)      # Read button state

        """Since we use pull-up the logic will be inverted"""
        gpio.output(led, not state)

except KeyboardInterrupt:
    print ("Goodbye.")



__author__ = "Stefan Mavrodiev"
__copyright__ = "Copyright 2014, Olimex LTD"
__credits__ = ["Stefan Mavrodiev"]
__license__ = "GPL"
__version__ = "2.0"
__maintainer__ = __author__
__email__ = "support@olimex.com"


#!/usr/bin/env python
"""Read from the EEPROM chip on A20-OLinuXino-LIME2

On the board there is small chip U3. This is 16kb eeprom memory AT24C16BN.
The i2c address can be different, but on this specific board is 0x50.

The text will be big mess if python3 is used.
"""

from pyA20Lime2 import i2c

__author__ = "Stefan Mavrodiev"
__copyright__ = "Copyright 2014, Olimex LTD"
__credits__ = ["Stefan Mavrodiev"]
__license__ = "GPL"
__version__ = "2.0"
__maintainer__ = __author__
__email__ = "support@olimex.com"

eeprom_address = 0x50

"""Initialize i2c bus"""
i2c.init("/dev/i2c-1")
i2c.open(eeprom_address)

"""Set address pointer to the first"""
i2c.write([0x00])

print "Dump eeprom:"
print "="*24

print "    ",
for i in xrange(16):
    print " %x" % i,

print "\t",
for i in xrange(16):
    print "%x" % i,
print ""

"""Print data"""
for i in xrange(128):
    page = i2c.read(16)
    print "%03x:" % (i*0x10),
    for j in xrange(0, 16):
        print "%02x" % page[j],

    """Print characters"""
    print "\t",
    for j in xrange(16):
        if page[j] <= 126 and page[j] >= 32:
            print chr(page[j]),
        else:
            print '.',
    print ""

i2c.close()


from distutils.core import setup
from distutils.core import Extension
from distutils.command.build_ext import build_ext as _build_ext

import sys

processor_type = "sun7i"

try:
    input = raw_input
except NameError:
    pass


def print_color(text):
    """
    Print text in yellow :)
    :param text: String to be colored
    :return: Colored text
    """

    return '\033[0;33m' + text + '\033[0m'


def print_warning():
    """
    Print confirmation dialog
    :return:
    """
    print (print_color("Warning! ") + "Detected and target processor mismatch. ")


    var = input("Do you want to continue [Y/n]? ")
    if var == 'Y' or var == 'y':
        return
    else:
        print ("Abort.")
        sys.exit(1)


def check_processor():
    """
    Detect processor type
    :return:
    """
    cpuinfo = open("/proc/cpuinfo", 'r')
    for line in cpuinfo:
        if "Hardware" in line:
            processor = line.split(":")[1].rstrip()

            if "sun4i" in processor:
                print ("Detected processor: " + print_color(processor) + " (Probably Allwinner A10)")

            elif "sun5i" in processor:
                print ("Detected processor: " + print_color(processor) + " (Probably Allwinner A13)")

            elif "sun7i" in processor:
                print ("Detected processor: " + print_color(processor) + " (Probably Allwinner A20)")

            else:
                print ("Detected processor: " + print_color("unknown"))


            if processor_type not in processor:
                print_warning()

            return

    print ("No processor detected")
    print_warning()


class build_ext(_build_ext):
    def run(self):
        check_processor()
        _build_ext.run(self)


modules = [
    Extension('pyA20Lime2.gpio.gpio', sources=['pyA20Lime2/gpio/gpio_lib.c', 'pyA20Lime2/gpio/gpio.c']),

    Extension('pyA20Lime2.i2c', sources=['pyA20Lime2/i2c/i2c_lib.c', 'pyA20Lime2/i2c/i2c.c']),

    Extension('pyA20Lime2.spi', sources=['pyA20Lime2/spi/spi_lib.c', 'pyA20Lime2/spi/spi.c']),

    Extension('pyA20Lime2.gpio.connector', sources=['pyA20Lime2/gpio/connector/connector.c']),

    Extension('pyA20Lime2.gpio.port', sources=['pyA20Lime2/gpio/port/port.c']),

]

setup(
    name='pyA20Lime2',
    version='0.2.1',
    author='Stefan Mavrodiev',
    author_email='support@olimex.com',
    url='https://www.olimex.com/',
    license='MIT',
    packages=['pyA20Lime2', 'pyA20Lime2.gpio'],
    description='Control GPIO, I2C and SPI',
    long_description=open('README.txt').read() + open('CHANGES.txt').read(),
    classifiers=['Development Status :: 3 - Alpha',
                 'Environment :: Console',
                 'Intended Audience :: Developers',
                 'Intended Audience :: Education',
                 'License :: OSI Approved :: MIT License',
                 'Operating System :: POSIX :: Linux',
                 'Programming Language :: Python',
                 'Topic :: Home Automation',
                 'Topic :: Software Development :: Embedded Systems'
    ],
    ext_modules=modules,
    cmdclass={'build_ext': build_ext}
)
